@@ -5,6 +5,8 @@ from datetime import datetime
 import boto3
 from botocore.exceptions import ClientError as botocore_clienterror
 import sdc_helpers.utils as utils
+from sdc_engine_helpers.sagemaker.utils import \
+    build_resource_tags
 from sdc_engine_helpers.date_utils import DateUtils
 from sdc_engine_helpers.sagemaker.utils import name_from_base
 
@@ -22,19 +24,12 @@ class CampaignStateManager:
 
     """
     # pylint: disable=raise-missing-from
+    # default tag to dev environment
     resource_tags = [
         {
             'Key': 'environment',
             'Value': 'dev'
-        },
-        {
-            'Key': 'engine',
-            'Value': 'alice'
-        },
-        {
-            'Key': 'project',
-            'Value': 'recommend'
-        },
+        }
     ]
     date_utils = DateUtils()
     # vendor
@@ -78,7 +73,8 @@ class CampaignStateManager:
     def sagemaker_create_model(
             self,
             training_job_name: str,
-            container_image: str = None
+            container_image: str = None,
+            resource_tags: list = None
     ) -> str:
         """
             Create model from a trained model job using Sagemaker API.
@@ -117,17 +113,12 @@ class CampaignStateManager:
                 }
             )
 
-        model_tags = self.resource_tags
-        model_tags.append({
-            'Key': 'status',
-            'Value': 'active'
-        })
         try:
             _ = self.sagemaker.create_model(
                 ModelName=model_name,
                 ExecutionRoleArn=training_job_config['RoleArn'],
                 PrimaryContainer=primary_container,
-                Tags=model_tags
+                Tags=resource_tags
             )
 
         except botocore_clienterror as exception:
@@ -152,7 +143,8 @@ class CampaignStateManager:
             self,
             endpoint_name: str,
             training_job_name: str,
-            container_image: str = None
+            container_image: str = None,
+            **kwargs
     ):
         """
             (Call vendor API) Creates a endpoint config
@@ -165,20 +157,44 @@ class CampaignStateManager:
             Returns:
                 dict: contains names of new created resources
         """
+        client_code = kwargs.get("client_code", None)
+        service_slug = kwargs.get("service_slug", None)
+        engine_slug = kwargs.get("engine_slug", None)
         # each endpoint configuration needs unique name
         endpoint_config_name = name_from_base(
             endpoint_name,
             max_length=63,
             short=False
         )
-
+        resource_tags = build_resource_tags(
+            current_tags=self.resource_tags,
+            new_tags=[
+                {
+                    'Key': 'client',
+                    'Value': client_code
+                },
+                {
+                    'Key': 'environment',
+                    'Value': 'prod'
+                },
+                {
+                    'Key': 'engine',
+                    'Value': engine_slug
+                },
+                {
+                    'Key': 'service',
+                    'Value': service_slug
+                }
+            ]
+        )
         endpoint = self.sagemaker.describe_endpoint(
             EndpointName=endpoint_name
         )
 
         model_name = self.sagemaker_create_model(
             training_job_name=training_job_name,
-            container_image=container_image
+            container_image=container_image,
+            resource_tags=resource_tags
         )
 
         previous_endpoint_config = self.sagemaker.describe_endpoint_config(
@@ -429,7 +445,12 @@ class CampaignStateManager:
 
         return True
 
-    def update_state(self, campaign: dict, solution: dict):
+    def update_state(
+            self,
+            campaign: dict,
+            solution: dict,
+            **kwargs
+    ):
         """
             Run the update workflow for campaigns
 
@@ -440,6 +461,9 @@ class CampaignStateManager:
                 (dict): new campaign config
 
         """
+        client_code = kwargs.get("client_code", None)
+        service_slug = kwargs.get("service_slug", None)
+        engine_slug = kwargs.get("engine_slug", None)
         new_campaign = {
             'arn': None,
             'solution_version_arn': None,
@@ -451,7 +475,10 @@ class CampaignStateManager:
         response = self.sagemaker_update_campaign(
             endpoint_name=campaign.get('arn'),
             training_job_name=solution.get('arn'),
-            container_image=campaign.get('container_image', None)
+            container_image=campaign.get('container_image', None),
+            client_code=client_code,
+            service_slug=service_slug,
+            engine_slug=engine_slug
         )
 
         new_campaign['arn'] = response.get('EndpointName')
