@@ -214,7 +214,6 @@ class RecommendationsManager:
             return:
                 item_codes (list) : list of item codes
         """
-
         item_codes = []
 
         cache_key = create_resource_name(
@@ -225,6 +224,15 @@ class RecommendationsManager:
             ]
         )
 
+        # check that key exists
+        key_exists = self.redis_helper.redis_hexists(
+            hashkey=cache_key
+        )
+        print("Cached Key = {}".format(cache_key))
+        print("keys found = {}".format(key_exists))
+        if key_exists == 0:
+            raise Exception("ServerError: Item Code lookup could not be found in cache.")
+
         if from_cache:
             # encode item_id -> item_code
             item_codes = self.redis_helper.redis_hmget(
@@ -267,6 +275,15 @@ class RecommendationsManager:
             additional_details=[self.service.id, self.client.id, self.engine]
         )
 
+        # check that key exists
+        key_exists = self.redis_helper.redis_hexists(
+            hashkey=cache_key
+        )
+        print("Cached Key = {}".format(cache_key))
+        print("keys found = {}".format(key_exists))
+        if key_exists == 0:
+            raise Exception("ServerError: Item ID lookup could not be found in cache.")
+
         if from_cache:
             # decode item_codes -> item_ids
             item_ids = self.redis_helper.redis_hmget(
@@ -337,6 +354,12 @@ class RecommendationsManager:
             # decode application/json response
             response_decoded = json.loads(response['Body'].read().decode())
 
+
+            if isinstance(response_decoded, str):
+                # if decorded response still string
+                # assume error and raise
+                raise Exception(response_decoded)
+
             #extract itemcodes
             recommendations = [r['item_code'] for r in response_decoded]
 
